SystemOrganization addCategory: #ConfigurationOfFileMan!

Object subclass: #ConfigurationOfFileMan
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfFileMan'!

!ConfigurationOfFileMan class methodsFor: 'accessing' stamp: 'mu 10/25/2010 23:15'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfFileMan class methodsFor: 'accessing' stamp: 'mu 10/25/2010 23:15'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfFileMan class methodsFor: 'accessing' stamp: 'mu 10/25/2010 23:15'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfFileMan class methodsFor: 'accessing' stamp: 'mu 10/25/2010 23:15'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfFileMan class methodsFor: 'accessing' stamp: 'mu 10/25/2010 23:15'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfFileMan class methodsFor: 'accessing' stamp: 'mu 10/25/2010 23:15'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfFileMan class methodsFor: 'accessing' stamp: 'mu 10/25/2010 23:15'!
project

	^self new project! !

!ConfigurationOfFileMan class methodsFor: 'accessing' stamp: 'mu 10/25/2010 23:15'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfFileMan class methodsFor: 'development support' stamp: 'MasashiUmezawa 8/28/2015 20:10'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfFileMan methodsFor: 'baselines' stamp: 'mu 3/31/2011 16:57'!
baseline03: spec
	<version: '0.3-baseline'>

	spec for: #common do:[
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/FileMan'.
		spec repository: 'http://squeaksource.blueplane.jp/FileMan'.
		spec description: 'FileMan 0.3 baseline'.
		
		spec package: 'FileMan-Core'.
		
		spec package: 'FileMan-Test' 
			with: [spec requires: #('FileMan-Core')].
		spec package: 'FileMan-Example' 
			with: [spec requires: #('FileMan-Test')].
			
		spec
			group: 'default' with: #('Core' 'Examples' 'Tests');
			group: 'Core' with: #('FileMan-Core');
			group: 'Examples' with: #('FileMan-Example' );
			group: 'Tests' with: #('FileMan-Test' ).	
	].
! !

!ConfigurationOfFileMan methodsFor: 'baselines' stamp: 'mu 4/25/2013 23:01'!
baseline04: spec
	<version: '0.4-baseline'>

	spec for: #common do:[
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/FileMan'.
		spec repository: 'http://squeaksource.blueplane.jp/FileMan'.
		spec description: 'FileMan 0.4 baseline'.
		
		spec package: 'FileMan-Core'.
		
		spec package: 'FileMan-Squeak'.
		spec group: 'Dialect' with: #('FileMan-Squeak').
		
		spec package: 'FileMan-Adaptor-FileDirectory' with: [spec requires: #('FileMan-Core' 'Dialect')].
		spec package: 'FileMan-Adaptor-FileSystem' with: [spec requires: #('FileMan-Core' 'Dialect')].
		spec for: #squeak do:[spec group: 'Adapter' with: #('FileMan-Adaptor-FileDirectory')].
		spec for: #pharo do:[spec group: 'Adapter' with: #('FileMan-Adaptor-FileSystem')].
		
		spec
			group: 'Core' with: #('FileMan-Core');
			group: 'Examples' with: #('FileMan-Example' );
			group: 'Tests' with: #('FileMan-Test' ).
			
		spec group: 'default' with: #('Core' 'Dialect' 'Adapter' 'Examples' 'Tests').
	].
! !

!ConfigurationOfFileMan methodsFor: 'symbolic versions' stamp: 'mu 4/25/2013 22:25'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #notDefined.
! !

!ConfigurationOfFileMan methodsFor: 'accessing' stamp: 'mu 10/25/2010 23:15'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfFileMan methodsFor: 'symbolic versions' stamp: 'mu 4/25/2013 22:26'!
stable: spec 
	<symbolicVersion: #stable>
	spec for: #'pharo2.0.x' version: '0.4.0'. 
	! !

!ConfigurationOfFileMan methodsFor: 'versions' stamp: 'mu 10/25/2010 23:42'!
version037: spec
	<version: '0.3.7' imports: #('0.3-baseline')>

	spec for: #common do:[
		spec blessing: #beta.
		
		spec 
			package: 'FileMan-Core' with: 'FileMan-Core-mu.1';
			package: 'FileMan-Example' with: 'FileMan-Example-mu.1';
			package: 'FileMan-Test' with: 'FileMan-Test-mu.1'.
	].! !

!ConfigurationOfFileMan methodsFor: 'versions' stamp: 'mu 6/3/2012 13:39'!
version038: spec
	<version: '0.3.8' imports: #('0.3-baseline')>

	spec for: #common do:[
		spec blessing: #beta.
		
		spec 
			package: 'FileMan-Core' with: 'FileMan-Core-mu.2';
			package: 'FileMan-Example' with: 'FileMan-Example-mu.1';
			package: 'FileMan-Test' with: 'FileMan-Test-mu.1'.
	].! !

!ConfigurationOfFileMan methodsFor: 'versions' stamp: 'mu 4/25/2013 23:34'!
version040: spec
	<version: '0.4.0' imports: #('0.4-baseline')>
	spec for: #common do:[
		spec blessing: #beta.
		spec 
			package: 'FileMan-Core' with: 'FileMan-Core-mu.15';
			package: 'FileMan-Example' with: 'FileMan-Example-mu.1';
			package: 'FileMan-Test' with: 'FileMan-Test-mu.2'.
	].
	spec for: #squeakCommon do:[
		spec package: 'FileMan-Squeak' with: 'FileMan-Squeak-mu.3'
	].
	spec for: #squeak do:[
		spec package: 'FileMan-Adaptor-FileDirectory' with: 'FileMan-Adaptor-FileDirectory-mu.4'
	].
	spec for: #pharo do:[
		spec package: 'FileMan-Adaptor-FileSystem' with: 'FileMan-Adaptor-FileSystem-MasashiUmezawa.6'
	].! !

!ConfigurationOfFileMan methodsFor: 'versions' stamp: 'MasashiUmezawa 8/28/2015 20:08'!
version041: spec
	<version: '0.4.1' imports: #('0.4-baseline')>
	spec for: #common do:[
		spec blessing: #beta.
		spec 
			package: 'FileMan-Core' with: 'FileMan-Core-MasashiUmezawa.17';
			package: 'FileMan-Example' with: 'FileMan-Example-mu.1';
			package: 'FileMan-Test' with: 'FileMan-Test-mu.3'.
	].
	spec for: #squeakCommon do:[
		spec package: 'FileMan-Squeak' with: 'FileMan-Squeak-mu.3'
	].
	spec for: #squeak do:[
		spec package: 'FileMan-Adaptor-FileDirectory' with: 'FileMan-Adaptor-FileDirectory-mu.5'
	].
	spec for: #pharo do:[
		spec package: 'FileMan-Adaptor-FileSystem' with: 'FileMan-Adaptor-FileSystem-MasashiUmezawa.7'
	].! !
